# aigve

:::aigve

--------------------

## Organization of this Library
* [aigve.configs](../configs/index.md)
* [aigve.core](../core/index.md)
* [aigve.datasets](../datasets/index.md)
* [aigve.metrics](../metrics/index.md)
* [aigve.utils](../utils/index.md)